@@ -6,6 +6,10 @@
 #include "GVAccess.h"
 #include "MobileWebPage.h"
 
+// For some reason the symbian MOC doesn't like it if I don't include QObject
+// even though it is present in QtCore which is included in global.h
+#include <QObject>
+
 class GVWebPage : public GVAccess
 {
     Q_OBJECT
