@@ -12,6 +12,10 @@
 #include "OsDependent.h"
 #include "Singletons.h"
 
+// For some reason the symbian MOC doesn't like it if I don't include QObject
+// even though it is present in QtCore which is included in global.h
+#include <QObject>
+
 class MainWindow : public QDeclarativeView
 {
     Q_OBJECT
